@@ -1,66 +1,76 @@
+use 5.006;    # our
 use strict;
 use warnings;
+
 package Search::GIN::Extract::ClassMap::Like;
-BEGIN {
-  $Search::GIN::Extract::ClassMap::Like::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Search::GIN::Extract::ClassMap::Like::VERSION = '0.01060817';
-}
 
-# ABSTRACT: Map Extractors based on what an object 'isa' or 'does'
+# ABSTRACT: Map Extractors based on what an objects inheritance or roles
 
-# $Id:$
-use Moose;
-use MooseX::Types::Moose qw( :all );
+our $VERSION = '1.000000';
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose qw( with blessed );
 use namespace::autoclean;
 
-
 with 'Search::GIN::Extract::ClassMap::Role';
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 sub matches {
-  my ( $self, $object ) = @_;
+  my ( $self, $extractee ) = @_;
   my @m;
-  return @m if not blessed $object;
+  return @m if not blessed $extractee;
   for my $class ( $self->classmap_entries ) {
-    if ( $object->isa($class) or $object->does($class) ) {
+    if ( $extractee->isa($class) or $extractee->does($class) ) {
       push @m, $self->classmap_get($class);
     }
   }
   return @m;
 }
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Search::GIN::Extract::ClassMap::Like - Map Extractors based on what an object 'isa' or 'does'
+Search::GIN::Extract::ClassMap::Like - Map Extractors based on what an objects inheritance or roles
 
 =head1 VERSION
 
-version 0.01060817
-
-=head1 ROLES
-
-=head2 L<Search::GIN::Extract::ClassMap::Role>
+version 1.000000
 
 =head1 METHODS
 
-=head2 matches
+=head2 C<matches>
+
+  # List of Search::GIN::Extract objects
+  my ( @extractors ) = $like_object->matches( $extractee );
 
 returns a list of extractors that are in the map for the object.
 
-=head3 signature: ->matches( $object )
-
-=head3 return: Search::GIN::Extract @items
+  for my $extractor ( @extractors ) {
+    my $metadata = $extractor->extract_values( $extractee );
+  }
 
 =head1 AUTHOR
 
@@ -68,7 +78,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
